<template>
    <nav class="pc-sidebar">
        <div class="navbar-wrapper">
            <div class="m-header">
                <Link href="/user/dashboard" class="b-brand text-primary">
                    <img src="/images/logo.png" alt="logo" style="max-width: 60px; height: auto;" />
                </Link>
            </div>

            <div class="navbar-content">
                <ul class="pc-navbar">
                    <li class="pc-item pc-caption">
                        <i class="ti ti-menu-2"></i>
                    </li>

                    <li
                        v-for="(item, index) in nav"
                        :key="index"
                        :class="['pc-item', { 'pc-hasmenu': item.children, active: isActive(item) || isActiveParent(item), 'pc-trigger': expanded[index] }]"
                    >
                        <!-- Menu tanpa children -->
                        <Link
                            v-if="!item.children"
                            :href="item.path"
                            class="pc-link"
                        >
                            <span class="pc-micon"><i :class="item.iconClass"></i></span>
                            <span class="pc-mtext">{{ item.title }}</span>
                        </Link>

                        <!-- Menu dengan children -->
                        <div v-else class="pc-link" @click="toggle(index)">
                            <span class="pc-micon"><i :class="item.iconClass"></i></span>
                            <span class="pc-mtext">{{ item.title }}</span>
                            <span class="pc-arrow"><i class="ti ti-chevron-right"></i></span>
                        </div>

                        <!-- Submenu -->
                        <ul v-if="item.children" class="pc-submenu">
                            <li
                                v-for="(child, childIndex) in item.children"
                                :key="childIndex"
                                class="pc-item"
                            >
                                <Link :href="child.path" class="pc-link">
                                    {{ child.title }}
                                </Link>
                            </li>
                        </ul>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
</template>

<script setup>
import { ref, reactive, onMounted, watchEffect } from 'vue';
import { Link, usePage } from '@inertiajs/vue3';

const page = usePage();

const nav = ref([
    {
        path: '/user/dashboard',
        title: 'Dashboard',
        iconClass: 'ti ti-home',
    },
    {
        path: '/user/tracer-study',
        title: 'Tracer Study',
        iconClass: 'ti ti-file-text',
    },
    {
        title: 'Portal Job',
        iconClass: 'ti ti-briefcase',
        children: [
            {
                title: 'Job Vacancies',
                path: '/user/job?status=all',
            },
            {
                title: 'Job Application',
                path: '/user/job?status=applied',
            }
        ]
    },
    {
        title: 'Profile',
        iconClass: 'ti ti-user',
        children: [
            {
                title: 'Public Profile',
                path: '/user/public-profile',
            },
            {
                title: 'Setting',
                path: '/user/profile',
            }
        ]
    },
    {
        path: '/user/logout',
        title: 'Logout',
        iconClass: 'ti ti-logout',
    }
]);

const expanded = reactive({});

const toggle = (index) => {
    console.log('index', index);
    expanded[index] = !expanded[index];
    console.log('expanded', expanded[index]);
    nav.value.forEach((item, idx) => {
        if (idx !== index) {
            expanded[idx] = false;
        }
    });
};

const isActive = (item) => {
    return page.url === item.path;
};

const isActiveParent = (item) => {
    if (item.children) {
        return item.children.some(child => page.url.startsWith(child.path));
    }
    return false;
};

// Inisialisasi menu yang aktif saat mounted
onMounted(() => {
    nav.value.forEach((item, index) => {
        if (item.children && isActiveParent(item)) {
            expanded[index] = true;
        } else if (item.children && expanded[index] === undefined) {
            expanded[index] = false;
        }
    });
});
</script>
